@@ -4,9 +4,18 @@ import scipy.sparse
 from functools import wraps
 from itertools import chain
 from collections.abc import Iterable
+from scipy.sparse import spmatrix
+from numba import literal_unroll
+import warnings
 
 from ._sparse_array import SparseArray
-from ._utils import check_compressed_axes, normalize_axis, check_zero_fill_value
+from ._utils import (
+    check_compressed_axes,
+    normalize_axis,
+    check_zero_fill_value,
+    equivalent,
+    _zero_of_dtype,
+)
 
 from ._umath import elemwise
 from ._coo.common import (
@@ -33,23 +42,67 @@ from ._coo.common import (
 )
 
 
+@numba.njit
+def nan_check(*args):
+    """
+    Check for the NaN values in Numpy Arrays
+
+    Parameters
+    ----------
+    Union[Numpy Array, Integer, Float]
+
+    Returns
+    -------
+    Boolean Whether Numpy Array Contains NaN
+
+    """
+    for i in literal_unroll(args):
+        ia = np.asarray(i)
+        if ia.size != 0 and np.isnan(np.min(ia)):
+            return True
+    return False
+
+
+def check_class_nan(test):
+    """
+    Check NaN for Sparse Arrays
+
+    Parameters
+    ----------
+    test : Union[sparse.COO, sparse.GCXS, scipy.sparse.spmatrix, Numpy Ndarrays]
+
+    Returns
+    -------
+    Boolean Whether Sparse Array Contains NaN
+
+    """
+    from ._compressed import GCXS
+    from ._coo import COO
+
+    if isinstance(test, (GCXS, COO)):
+        return nan_check(test.fill_value, test.data)
+    elif isinstance(test, spmatrix):
+        return nan_check(test.data)
+    else:
+        return nan_check(test)
+
+
 def tensordot(a, b, axes=2, *, return_type=None):
     """
     Perform the equivalent of :obj:`numpy.tensordot`.
 
     Parameters
     ----------
-    a, b : Union[COO, np.ndarray, scipy.sparse.spmatrix]
+    a, b : Union[SparseArray, np.ndarray, scipy.sparse.spmatrix]
         The arrays to perform the :code:`tensordot` operation on.
     axes : tuple[Union[int, tuple[int], Union[int, tuple[int]], optional
         The axes to match when performing the sum.
     return_type : {None, COO, np.ndarray}, optional
         Type of returned array.
 
-
     Returns
     -------
-    Union[COO, numpy.ndarray]
+    Union[SparseArray, numpy.ndarray]
         The result of the operation.
 
     Raises
@@ -151,12 +204,12 @@ def matmul(a, b):
 
     Parameters
     ----------
-    a, b : Union[COO, np.ndarray, scipy.sparse.spmatrix]
+    a, b : Union[SparseArray, np.ndarray, scipy.sparse.spmatrix]
         The arrays to perform the :code:`matmul` operation on.
 
     Returns
     -------
-    Union[COO, numpy.ndarray]
+    Union[SparseArray, numpy.ndarray]
         The result of the operation.
 
     Raises
@@ -175,6 +228,11 @@ def matmul(a, b):
             "Cannot perform dot product on types %s, %s" % (type(a), type(b))
         )
 
+    if check_class_nan(a) or check_class_nan(b):
+        warnings.warn(
+            "Nan will not be propagated in matrix multiplication", RuntimeWarning
+        )
+
     # When b is 2-d, it is equivalent to dot
     if b.ndim <= 2:
         return dot(a, b)
@@ -229,12 +287,12 @@ def dot(a, b):
 
     Parameters
     ----------
-    a, b : Union[COO, np.ndarray, scipy.sparse.spmatrix]
+    a, b : Union[SparseArray, np.ndarray, scipy.sparse.spmatrix]
         The arrays to perform the :code:`dot` operation on.
 
     Returns
     -------
-    Union[COO, numpy.ndarray]
+    Union[SparseArray, numpy.ndarray]
         The result of the operation.
 
     Raises
@@ -449,6 +507,11 @@ def _dot(a, b, return_type=None):
             return out.asformat("gcxs")
         return out
 
+    if isinstance(a, np.ndarray) and isinstance(b, np.ndarray):
+        return np.dot(a, b)
+
+    raise TypeError("Unsupported types.")
+
 
 def _memoize_dtype(f):
     """
@@ -497,18 +560,13 @@ def _csr_csr_count_nnz(
     with compressed rows: (a @ b).nnz.
 
     Parameters
-        ----------
-        out_shape : tuple
-            The shape of the output array.
-
-        indptr : ndarray
-            The empty index pointer array for the output.
-
-        a_indices, a_indptr : np.ndarray
-            The indices and index pointer array of ``a``.
-
-        b_data, b_indices, b_indptr : np.ndarray
-            The indices and index pointer array of ``b``.
+    ----------
+    out_shape : tuple
+        The shape of the output array.
+    a_indices, a_indptr : np.ndarray
+        The indices and index pointer array of ``a``.
+    b_data, b_indices, b_indptr : np.ndarray
+        The indices and index pointer array of ``b``.
     """
     n_row, n_col = out_shape
     nnz = 0
@@ -534,18 +592,15 @@ def _csr_ndarray_count_nnz(
     numpy array: (a @ b).nnz.
 
     Parameters
-        ----------
-        out_shape : tuple
-            The shape of the output array.
-
-        indptr : ndarray
-            The empty index pointer array for the output.
-
-        a_indices, a_indptr : np.ndarray
-            The indices and index pointer array of ``a``.
-
-        b : np.ndarray
-            The second input array ``b``.
+    ----------
+    out_shape : tuple
+        The shape of the output array.
+    indptr : ndarray
+        The empty index pointer array for the output.
+    a_indices, a_indptr : np.ndarray
+        The indices and index pointer array of ``a``.
+    b : np.ndarray
+        The second input array ``b``.
     """
     nnz = 0
     for i in range(out_shape[0]):
@@ -569,18 +624,15 @@ def _csc_ndarray_count_nnz(
     numpy array: (a @ b).nnz.
 
     Parameters
-        ----------
-        a_shape, b_shape : tuple
-            The shapes of the input arrays.
-
-        indptr : ndarray
-            The empty index pointer array for the output.
-
-        a_indices, a_indptr : np.ndarray
-            The indices and index pointer array of ``a``.
-
-        b : np.ndarray
-            The second input array ``b``.
+    ----------
+    a_shape, b_shape : tuple
+        The shapes of the input arrays.
+    indptr : ndarray
+        The empty index pointer array for the output.
+    a_indices, a_indptr : np.ndarray
+        The indices and index pointer array of ``a``.
+    b : np.ndarray
+        The second input array ``b``.
     """
     nnz = 0
     mask = np.full(a_shape[0], -1)
@@ -597,7 +649,7 @@ def _csc_ndarray_count_nnz(
 
 
 def _dot_dtype(dt1, dt2):
-    return (np.zeros((), dtype=dt1) * np.zeros((), dtype=dt1)).dtype
+    return (np.zeros((), dtype=dt1) * np.zeros((), dtype=dt2)).dtype
 
 
 @_memoize_dtype
@@ -620,10 +672,8 @@ def _dot_csr_csr_type(dt1, dt2):
         ----------
         out_shape : tuple
             The shape of the output array.
-
         a_data, a_indices, a_indptr : np.ndarray
             The data, indices, and index pointer arrays of ``a``.
-
         b_data, b_indices, b_indptr : np.ndarray
             The data, indices, and index pointer arrays of ``b``.
         """
@@ -697,10 +747,8 @@ def _dot_csr_ndarray_type(dt1, dt2):
         ----------
         a_data, a_indices, a_indptr : np.ndarray
             The data, indices, and index pointers of ``a``.
-
         b : np.ndarray
             The second input array ``b``.
-
         out_shape : Tuple[int]
             The shape of the output array.
         """
@@ -739,10 +787,8 @@ def _dot_csr_ndarray_type_sparse(dt1, dt2):
         ----------
         a_data, a_indices, a_indptr : np.ndarray
             The data, indices, and index pointers of ``a``.
-
         b : np.ndarray
             The second input array ``b``.
-
         out_shape : Tuple[int]
             The shape of the output array.
         """
@@ -792,10 +838,8 @@ def _dot_csc_ndarray_type_sparse(dt1, dt2):
         ----------
         a_data, a_indices, a_indptr : np.ndarray
             The data, indices, and index pointers of ``a``.
-
         b : np.ndarray
             The second input array ``b``.
-
         a_shape, b_shape : Tuple[int]
             The shapes of the input arrays.
         """
@@ -858,10 +902,8 @@ def _dot_csc_ndarray_type(dt1, dt2):
         ----------
         a_data, a_indices, a_indptr : np.ndarray
             The data, indices, and index pointers of ``a``.
-
         b : np.ndarray
             The second input array ``b``.
-
         a_shape, b_shape : Tuple[int]
             The shapes of the input arrays.
         """
@@ -893,10 +935,8 @@ def _dot_ndarray_csc_type(dt1, dt2):
         ----------
         a : np.ndarray
             The input array ``a``.
-
         b_data, b_indices, b_indptr : np.ndarray
             The data, indices, and index pointers of ``b``.
-
         out_shape : Tuple[int]
             The shape of the output array.
         """
@@ -932,10 +972,8 @@ def _dot_coo_coo_type(dt1, dt2):
         ----------
         a_shape, b_shape : tuple
             The shapes of the input arrays.
-
         a_data, a_coords : np.ndarray
             The data and coordinates of ``a``.
-
         b_data, b_coords : np.ndarray
             The data and coordinates of ``b``.
         """
@@ -1006,10 +1044,8 @@ def _dot_coo_ndarray_type(dt1, dt2):
         ----------
         data1, coords1 : np.ndarray
             The data and coordinates of ``s1``.
-
         array2 : np.ndarray
             The second input array ``x2``.
-
         out_shape : Tuple[int]
             The output shape.
         """
@@ -1050,10 +1086,8 @@ def _dot_coo_ndarray_type_sparse(dt1, dt2):
         ----------
         data1, coords1 : np.ndarray
             The data and coordinates of ``s1``.
-
         array2 : np.ndarray
             The second input array ``x2``.
-
         out_shape : Tuple[int]
             The output shape.
         """
@@ -1105,10 +1139,8 @@ def _dot_ndarray_coo_type(dt1, dt2):
         ----------
         array1 : np.ndarray
             The input array ``x1``.
-
         data2, coords2 : np.ndarray
             The data and coordinates of ``s2``.
-
         out_shape : Tuple[int]
             The output shape.
         """
@@ -1142,10 +1174,8 @@ def _dot_ndarray_coo_type_sparse(dt1, dt2):
         ----------
         array1 : np.ndarray
             The input array ``x1``.
-
         data2, coords2 : np.ndarray
             The data and coordinates of ``s2``.
-
         out_shape : Tuple[int]
             The output shape.
         """
@@ -1208,9 +1238,9 @@ def stack(arrays, axis=0, compressed_axes=None):
     --------
     numpy.stack : NumPy equivalent function
     """
-    from ._coo import COO
+    from ._compressed import GCXS
 
-    if any(isinstance(arr, COO) for arr in arrays):
+    if not all(isinstance(arr, GCXS) for arr in arrays):
         from ._coo import stack as coo_stack
 
         return coo_stack(arrays, axis)
@@ -1247,9 +1277,9 @@ def concatenate(arrays, axis=0, compressed_axes=None):
     --------
     numpy.concatenate : NumPy equivalent function
     """
-    from ._coo import COO
+    from ._compressed import GCXS
 
-    if any(isinstance(arr, COO) for arr in arrays):
+    if not all(isinstance(arr, GCXS) for arr in arrays):
         from ._coo import concatenate as coo_concat
 
         return coo_concat(arrays, axis)
@@ -1259,7 +1289,7 @@ def concatenate(arrays, axis=0, compressed_axes=None):
         return gcxs_concat(arrays, axis, compressed_axes)
 
 
-def eye(N, M=None, k=0, dtype=float, format="coo", compressed_axes=None):
+def eye(N, M=None, k=0, dtype=float, format="coo", **kwargs):
     """Return a 2-D array in the specified format with ones on the diagonal and zeros elsewhere.
 
     Parameters
@@ -1276,8 +1306,6 @@ def eye(N, M=None, k=0, dtype=float, format="coo", compressed_axes=None):
         Data-type of the returned array.
     format : str, optional
         A format string.
-    compressed_axes : iterable, optional
-        The axes to compress if returning a GCXS array.
 
     Returns
     -------
@@ -1322,10 +1350,10 @@ def eye(N, M=None, k=0, dtype=float, format="coo", compressed_axes=None):
 
     return COO(
         coords, data=data, shape=(N, M), has_duplicates=False, sorted=True
-    ).asformat(format, compressed_axes=compressed_axes)
+    ).asformat(format, **kwargs)
 
 
-def full(shape, fill_value, dtype=None, format="coo", compressed_axes=None):
+def full(shape, fill_value, dtype=None, format="coo", order="C", **kwargs):
     """Return a SparseArray of given shape and type, filled with `fill_value`.
 
     Parameters
@@ -1341,6 +1369,10 @@ def full(shape, fill_value, dtype=None, format="coo", compressed_axes=None):
         A format string.
     compressed_axes : iterable, optional
         The axes to compress if returning a GCXS array.
+    order : {'C', None}
+        Values except these are not currently supported and raise a
+        NotImplementedError.
+
     Returns
     -------
     out : SparseArray
@@ -1361,8 +1393,8 @@ def full(shape, fill_value, dtype=None, format="coo", compressed_axes=None):
         dtype = np.array(fill_value).dtype
     if not isinstance(shape, tuple):
         shape = (shape,)
-    if compressed_axes is not None:
-        check_compressed_axes(shape, compressed_axes)
+    if order not in {"C", None}:
+        raise NotImplementedError("Currently, only 'C' and None are supported.")
     data = np.empty(0, dtype=dtype)
     coords = np.empty((len(shape), 0), dtype=np.intp)
     return COO(
@@ -1372,10 +1404,10 @@ def full(shape, fill_value, dtype=None, format="coo", compressed_axes=None):
         fill_value=fill_value,
         has_duplicates=False,
         sorted=True,
-    ).asformat(format, compressed_axes=compressed_axes)
+    ).asformat(format, **kwargs)
 
 
-def full_like(a, fill_value, dtype=None, shape=None, format=None, compressed_axes=None):
+def full_like(a, fill_value, dtype=None, shape=None, format=None, **kwargs):
     """Return a full array with the same shape and type as a given array.
 
     Parameters
@@ -1412,11 +1444,11 @@ def full_like(a, fill_value, dtype=None, shape=None, format=None, compressed_axe
         fill_value,
         dtype=(a.dtype if dtype is None else dtype),
         format=format,
-        compressed_axes=compressed_axes,
+        **kwargs,
     )
 
 
-def zeros(shape, dtype=float, format="coo", compressed_axes=None):
+def zeros(shape, dtype=float, format="coo", **kwargs):
     """Return a SparseArray of given shape and type, filled with zeros.
 
     Parameters
@@ -1445,14 +1477,10 @@ def zeros(shape, dtype=float, format="coo", compressed_axes=None):
     array([[0, 0],
            [0, 0]])
     """
-    if compressed_axes is not None:
-        check_compressed_axes(shape, compressed_axes)
-    return full(shape, 0, np.dtype(dtype)).asformat(
-        format, compressed_axes=compressed_axes
-    )
+    return full(shape, 0, np.dtype(dtype)).asformat(format, **kwargs)
 
 
-def zeros_like(a, dtype=None, shape=None, format=None, compressed_axes=None):
+def zeros_like(a, dtype=None, shape=None, format=None, **kwargs):
     """Return a SparseArray of zeros with the same shape and type as ``a``.
 
     Parameters
@@ -1478,12 +1506,10 @@ def zeros_like(a, dtype=None, shape=None, format=None, compressed_axes=None):
     array([[0, 0, 0],
            [0, 0, 0]])
     """
-    return full_like(
-        a, 0, dtype=dtype, shape=shape, format=format, compressed_axes=compressed_axes
-    )
+    return full_like(a, 0, dtype=dtype, shape=shape, format=format, **kwargs)
 
 
-def ones(shape, dtype=float, format="coo", compressed_axes=None):
+def ones(shape, dtype=float, format="coo", **kwargs):
     """Return a SparseArray of given shape and type, filled with ones.
 
     Parameters
@@ -1512,14 +1538,10 @@ def ones(shape, dtype=float, format="coo", compressed_axes=None):
     array([[1, 1],
            [1, 1]])
     """
-    if compressed_axes is not None:
-        check_compressed_axes(shape, compressed_axes)
-    return full(shape, 1, np.dtype(dtype)).asformat(
-        format, compressed_axes=compressed_axes
-    )
+    return full(shape, 1, np.dtype(dtype)).asformat(format, **kwargs)
 
 
-def ones_like(a, dtype=None, shape=None, format=None, compressed_axes=None):
+def ones_like(a, dtype=None, shape=None, format=None, **kwargs):
     """Return a SparseArray of ones with the same shape and type as ``a``.
 
     Parameters
@@ -1545,9 +1567,7 @@ def ones_like(a, dtype=None, shape=None, format=None, compressed_axes=None):
     array([[1, 1, 1],
            [1, 1, 1]])
     """
-    return full_like(
-        a, 1, dtype=dtype, shape=shape, format=format, compressed_axes=compressed_axes
-    )
+    return full_like(a, 1, dtype=dtype, shape=shape, format=format, **kwargs)
 
 
 def outer(a, b, out=None):
@@ -1611,7 +1631,7 @@ def moveaxis(a, source, destination):
 
     Parameters
     ----------
-    a : COO
+    a : SparseArray
         The array whose axes should be reordered.
     source : int or List[int]
         Original positions of the axes to move. These must be unique.
@@ -1620,7 +1640,7 @@ def moveaxis(a, source, destination):
 
     Returns
     -------
-    COO
+    SparseArray
         Array with moved axes.
 
     Examples
@@ -1653,3 +1673,82 @@ def moveaxis(a, source, destination):
 
     result = a.transpose(order)
     return result
+
+
+def pad(array, pad_width, mode="constant", **kwargs):
+    """
+    Performs the equivalent of :obj:`numpy.pad` for :obj:`SparseArray`. Note that
+    this function returns a new array instead of a view.
+
+    Parameters
+    ----------
+    array : SparseArray
+        Sparse array which is to be padded.
+
+    pad_width : {sequence, array_like, int}
+        Number of values padded to the edges of each axis. ((before_1, after_1), … (before_N, after_N)) unique pad widths for each axis. ((before, after),) yields same before and after pad for each axis. (pad,) or int is a shortcut for before = after = pad width for all axes.
+
+    mode : str
+        Pads to a constant value which is fill value. Currently only constant mode is implemented
+
+    constant_values : int
+        The values to set the padded values for each axis. Default is 0. This must be same as fill value.
+
+    Returns
+    -------
+    SparseArray
+        The padded sparse array.
+
+    Raises
+    ------
+    NotImplementedError
+        If mode != 'constant' or there are unknown arguments.
+
+    ValueError
+        If constant_values != self.fill_value
+
+    See Also
+    --------
+    :obj:`numpy.pad` : NumPy equivalent function
+
+    """
+    if not isinstance(array, SparseArray):
+        raise NotImplementedError("Input array is not compatible.")
+
+    if mode.lower() != "constant":
+        raise NotImplementedError(f"Mode '{mode}' is not yet supported.")
+
+    if not equivalent(
+        kwargs.pop("constant_values", _zero_of_dtype(array.dtype)), array.fill_value
+    ):
+        raise ValueError("constant_values can only be equal to fill value.")
+
+    if kwargs:
+        raise NotImplementedError("Additional Unknown arguments present.")
+
+    from ._coo import COO
+
+    array = array.asformat("coo")
+
+    pad_width = np.broadcast_to(pad_width, (len(array.shape), 2))
+    new_coords = array.coords + pad_width[:, 0:1]
+    new_shape = tuple(
+        [
+            array.shape[i] + pad_width[i, 0] + pad_width[i, 1]
+            for i in range(len(array.shape))
+        ]
+    )
+    new_data = array.data
+    return COO(new_coords, new_data, new_shape, fill_value=array.fill_value)
+
+
+def format_to_string(format):
+    if isinstance(format, type):
+        if not issubclass(format, SparseArray):
+            raise ValueError(f"invalid format: {format}")
+        format = format.__name__.lower()
+
+    if isinstance(format, str):
+        return format
+
+    raise ValueError(f"invalid format: {format}")
