@@ -1,2 +1,2 @@
-from .compressed import GCXS
+from .compressed import GCXS, CSC, CSR
 from .common import stack, concatenate
