@@ -382,24 +382,19 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         x = np.asanyarray(x).view(type=np.ndarray)
 
         if fill_value is None:
-            fill_value = _zero_of_dtype(x.dtype)
+            fill_value = _zero_of_dtype(x.dtype) if x.shape else x
 
-        if x.shape:
-            coords = np.where(~equivalent(x, fill_value))
-            data = x[coords]
-            coords = np.vstack(coords)
-        else:
-            coords = np.empty((0, 1), dtype=np.uint8)
-            data = np.array(x, ndmin=1)
+        coords = np.atleast_2d(np.flatnonzero(~equivalent(x, fill_value)))
+        data = x.ravel()[tuple(coords)]
         return cls(
             coords,
             data,
-            shape=x.shape,
+            shape=x.size,
             has_duplicates=False,
             sorted=True,
             fill_value=fill_value,
             idx_dtype=idx_dtype,
-        )
+        ).reshape(x.shape)
 
     def todense(self):
         """
@@ -805,8 +800,10 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
 
         See Also
         --------
-        :obj:`COO.transpose` : A method where you can specify the order of the axes.
-        numpy.ndarray.T : Numpy equivalent property.
+        :obj:`COO.transpose` :
+            A method where you can specify the order of the axes.
+        numpy.ndarray.T :
+            Numpy equivalent property.
 
         Examples
         --------
@@ -845,7 +842,7 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         ----------
         axis1 : int
             first axis to swap
-        axis2: int
+        axis2 : int
             second axis to swap
 
         Returns
@@ -920,12 +917,6 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         The nonzero coordinates of a flattened version of this array. Note that
         the coordinates may be out of order.
 
-        Parameters
-        ----------
-        signed : bool, optional
-            Whether to use a signed datatype for the output array. :code:`False`
-            by default.
-
         Returns
         -------
         numpy.ndarray
@@ -977,21 +968,26 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
     def reshape(self, shape, order="C"):
         """
         Returns a new :obj:`COO` array that is a reshaped version of this array.
+
         Parameters
         ----------
         shape : tuple[int]
             The desired shape of the output array.
+
         Returns
         -------
         COO
             The reshaped output array.
+
         See Also
         --------
         numpy.ndarray.reshape : The equivalent Numpy function.
+
         Notes
         -----
         The :code:`order` parameter is provided just for compatibility with
         Numpy and isn't actually supported.
+
         Examples
         --------
         >>> s = COO.from_numpy(np.arange(25))
@@ -1114,7 +1110,6 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         ------
         ValueError
             If the array is not two-dimensional.
-
         ValueError
             If all the array doesn't zero fill-values.
 
@@ -1162,7 +1157,6 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         ------
         ValueError
             If the array is not two-dimensional.
-
         ValueError
             If all the array doesn't have zero fill-values.
 
@@ -1203,7 +1197,6 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         ------
         ValueError
             If the array is not two-dimensional.
-
         ValueError
             If the array doesn't have zero fill-values.
 
@@ -1331,7 +1324,7 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         ValueError
             If the operand cannot be broadcast to the given shape.
 
-        See also
+        See Also
         --------
         :obj:`numpy.broadcast_to` : NumPy equivalent function
         """
@@ -1355,7 +1348,7 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
             The dense array.
 
         Raises
-        -------
+        ------
         ValueError
             If the returned array would be too large.
 
@@ -1414,7 +1407,7 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         check_zero_fill_value(self)
         return tuple(self.coords)
 
-    def asformat(self, format, compressed_axes=None):
+    def asformat(self, format, **kwargs):
         """
         Convert this sparse array to a given format.
 
@@ -1433,25 +1426,27 @@ class COO(SparseArray, NDArrayOperatorsMixin):  # lgtm [py/missing-equals]
         NotImplementedError
             If the format isn't supported.
         """
-        from .._compressed import GCXS
+        from sparse._utils import convert_format
 
-        if format == "gcxs" or format is GCXS:
-            return GCXS.from_coo(self, compressed_axes=compressed_axes)
+        format = convert_format(format)
 
-        elif compressed_axes is not None:
-            raise ValueError(
-                "compressed_axes is not supported for {} format".format(format)
-            )
+        if format == "gcxs":
+            from .._compressed import GCXS
 
-        if format == "coo" or format is COO:
+            return GCXS.from_coo(self, **kwargs)
+
+        elif len(kwargs) != 0:
+            raise TypeError(f"Invalid keyword arguments provided: {kwargs}")
+
+        if format == "coo":
             return self
 
-        from .._dok import DOK
+        if format == "dok":
+            from .._dok import DOK
 
-        if format == "dok" or format is DOK:
-            return DOK.from_coo(self)
+            return DOK.from_coo(self, **kwargs)
 
-        raise NotImplementedError("The given format is not supported.")
+        return self.asformat("gcxs", **kwargs).asformat(format, **kwargs)
 
 
 def as_coo(x, shape=None, fill_value=None, idx_dtype=None):
@@ -1472,10 +1467,14 @@ def as_coo(x, shape=None, fill_value=None, idx_dtype=None):
 
     See Also
     --------
-    SparseArray.asformat : A utility function to convert between formats in this library.
-    COO.from_numpy : Convert a Numpy array to :obj:`COO`.
-    COO.from_scipy_sparse : Convert a SciPy sparse matrix to :obj:`COO`.
-    COO.from_iter : Convert an iterable to :obj:`COO`.
+    SparseArray.asformat :
+        A utility function to convert between formats in this library.
+    COO.from_numpy :
+        Convert a Numpy array to :obj:`COO`.
+    COO.from_scipy_sparse :
+        Convert a SciPy sparse matrix to :obj:`COO`.
+    COO.from_iter :
+        Convert an iterable to :obj:`COO`.
     """
     if hasattr(x, "shape") and shape is not None:
         raise ValueError(
@@ -1545,7 +1544,7 @@ def _grouped_reduce(x, groups, method, **kwargs):
         contiguous.
     method : np.ufunc
         The :code:`ufunc` to use to perform the reduction.
-    kwargs : dict
+    **kwargs : dict
         The kwargs to pass to the :code:`ufunc`'s :code:`reduceat`
         function.
 
