@@ -83,20 +83,20 @@ def random(
     random_state=None,
     data_rvs=None,
     format="coo",
-    compressed_axes=None,
     fill_value=None,
     idx_dtype=None,
+    **kwargs,
 ):
     """Generate a random sparse multidimensional array
 
     Parameters
     ----------
-    shape: Tuple[int]
+    shape : Tuple[int]
         Shape of the array
-    density: float, optional
+    density : float, optional
         Density of the generated array; default is 0.01.
         Mutually exclusive with `nnz`.
-    nnz: int, optional
+    nnz : int, optional
         Number of nonzero elements in the generated array.
         Mutually exclusive with `density`.
     random_state : Union[numpy.random.RandomState, int], optional
@@ -120,14 +120,11 @@ def random(
 
     See Also
     --------
-    :obj:`scipy.sparse.rand`
-        Equivalent Scipy function.
-    :obj:`numpy.random.rand`
-        Similar Numpy function.
+    :obj:`scipy.sparse.rand` : Equivalent Scipy function.
+    :obj:`numpy.random.rand` : Similar Numpy function.
 
     Examples
     --------
-
     >>> from sparse import random
     >>> from scipy import stats
     >>> rvs = lambda x: stats.poisson(25, loc=10).rvs(x, random_state=np.random.RandomState(1))
@@ -164,11 +161,6 @@ def random(
             "for an array with {} total elements".format(nnz, elements)
         )
 
-    if format != "gcxs" and compressed_axes is not None:
-        raise ValueError(
-            "compressed_axes is not supported for {} format".format(format)
-        )
-
     if random_state is None:
         random_state = np.random
     elif isinstance(random_state, Integral):
@@ -206,7 +198,7 @@ def random(
                 "cannot cast array with shape {} to dtype {}.".format(shape, idx_dtype)
             )
 
-    return ar.asformat(format, compressed_axes=compressed_axes)
+    return ar.asformat(format, **kwargs)
 
 
 def isscalar(x):
@@ -327,12 +319,15 @@ def html_table(arr):
     table = "<table>"
     table += "<tbody>"
     headings = ["Format", "Data Type", "Shape", "nnz", "Density", "Read-only"]
+
+    density = np.float_(arr.nnz) / np.float_(arr.size)
+
     info = [
         type(arr).__name__.lower(),
         str(arr.dtype),
         str(arr.shape),
         str(arr.nnz),
-        str(arr.nnz / arr.size),
+        str(density),
     ]
 
     # read-only
@@ -344,7 +339,10 @@ def html_table(arr):
         headings.append("Storage ratio")
         info.append(
             "%.1f"
-            % (arr.nbytes / (reduce(operator.mul, arr.shape, 1) * arr.dtype.itemsize))
+            % (
+                np.float_(arr.nbytes)
+                / np.float_(reduce(operator.mul, arr.shape, 1) * arr.dtype.itemsize)
+            )
         )
 
     # compressed_axes
@@ -370,7 +368,7 @@ def check_compressed_axes(ndim, compressed_axes):
 
     Parameters
     ----------
-    shape : int
+    ndim : int
     compressed_axes : Iterable
 
     Raises
@@ -400,7 +398,7 @@ def check_zero_fill_value(*args):
 
     Parameters
     ----------
-    args : Iterable[SparseArray]
+    *args : Iterable[SparseArray]
 
     Raises
     ------
@@ -490,3 +488,16 @@ def can_store(dtype, scalar):
 
 def is_unsigned_dtype(dtype):
     return not np.array(-1, dtype=dtype) == np.array(-1)
+
+
+def convert_format(format):
+    from ._sparse_array import SparseArray
+
+    if isinstance(format, type):
+        if not issubclass(format, SparseArray):
+            raise ValueError(f"Invalid format: {format}")
+        return format.__name__.lower()
+    if isinstance(format, str):
+        return format
+
+    raise ValueError(f"Invalid format: {format}")
