@@ -432,3 +432,36 @@ def test_from_coo_valerr():
     a = sparse.random((25, 25, 25), density=0.01, format="coo")
     with pytest.raises(ValueError):
         GCXS.from_coo(a, idx_dtype=np.int8)
+
+
+@pytest.mark.parametrize(
+    "pad_width",
+    [
+        2,
+        (2, 1),
+        ((2), (1)),
+        ((1, 2), (4, 5), (7, 8)),
+    ],
+)
+@pytest.mark.parametrize("constant_values", [0, 1, 150, np.nan])
+def test_pad_valid(pad_width, constant_values):
+    y = sparse.random(
+        (50, 50, 3), density=0.15, fill_value=constant_values, format="gcxs"
+    )
+    x = y.todense()
+    xx = np.pad(x, pad_width=pad_width, constant_values=constant_values)
+    yy = np.pad(y, pad_width=pad_width, constant_values=constant_values)
+    assert_eq(xx, yy)
+
+
+@pytest.mark.parametrize(
+    "pad_width",
+    [
+        ((2, 1), (5, 7)),
+    ],
+)
+@pytest.mark.parametrize("constant_values", [150, 2, (1, 2)])
+def test_pad_invalid(pad_width, constant_values, fill_value=0):
+    y = sparse.random((50, 50, 3), density=0.15, format="gcxs")
+    with pytest.raises(ValueError):
+        np.pad(y, pad_width, constant_values=constant_values)
