@@ -2,6 +2,7 @@ import contextlib
 import operator
 import pickle
 import sys
+from functools import reduce
 
 import numpy as np
 import pytest
@@ -11,7 +12,7 @@ import scipy.stats
 import sparse
 from sparse import COO
 from sparse._settings import NEP18_ENABLED
-from sparse._utils import assert_eq, random_value_array
+from sparse._utils import assert_eq, random_value_array, html_table
 
 
 @pytest.fixture(scope="module", params=["f8", "f4", "i8", "i4"])
@@ -948,8 +949,8 @@ def test_two_random_same_seed():
     "rvs, dtype",
     [
         (None, np.float64),
-        (scipy.stats.poisson(25, loc=10).rvs, np.int),
-        (lambda x: np.random.choice([True, False], size=x), np.bool),
+        (scipy.stats.poisson(25, loc=10).rvs, np.int_),
+        (lambda x: np.random.choice([True, False], size=x), np.bool_),
     ],
 )
 @pytest.mark.parametrize("shape", [(2, 4, 5), (20, 40, 50)])
@@ -1015,7 +1016,7 @@ def test_np_array():
     ],
 )
 def test_three_arg_where(shapes):
-    cs = sparse.random(shapes[0], density=0.5).astype(np.bool)
+    cs = sparse.random(shapes[0], density=0.5).astype(np.bool_)
     xs = sparse.random(shapes[1], density=0.5)
     ys = sparse.random(shapes[2], density=0.5)
 
@@ -1051,7 +1052,7 @@ def test_one_arg_where_dense():
 
 
 def test_two_arg_where():
-    cs = sparse.random((2, 3, 4), density=0.5).astype(np.bool)
+    cs = sparse.random((2, 3, 4), density=0.5).astype(np.bool_)
     xs = sparse.random((2, 3, 4), density=0.5)
 
     with pytest.raises(ValueError):
@@ -1606,3 +1607,68 @@ def test_coo_valerr():
 def test_random_idx_dtype():
     with pytest.raises(ValueError):
         sparse.random((300,), density=0.1, format="coo", idx_dtype=np.int8)
+
+
+def test_html_for_size_zero():
+    arr = sparse.COO.from_numpy(np.array(()))
+    ground_truth = "<table><tbody>"
+    ground_truth += '<tr><th style="text-align: left">Format</th><td style="text-align: left">coo</td></tr>'
+    ground_truth += '<tr><th style="text-align: left">Data Type</th><td style="text-align: left">float64</td></tr>'
+    ground_truth += '<tr><th style="text-align: left">Shape</th><td style="text-align: left">(0,)</td></tr>'
+    ground_truth += '<tr><th style="text-align: left">nnz</th><td style="text-align: left">0</td></tr>'
+    ground_truth += '<tr><th style="text-align: left">Density</th><td style="text-align: left">nan</td></tr>'
+    ground_truth += '<tr><th style="text-align: left">Read-only</th><td style="text-align: left">True</td></tr>'
+    ground_truth += '<tr><th style="text-align: left">Size</th><td style="text-align: left">0</td></tr>'
+    ground_truth += '<tr><th style="text-align: left">Storage ratio</th><td style="text-align: left">nan</td></tr>'
+    ground_truth += "</tbody></table>"
+
+    table = html_table(arr)
+    assert table == ground_truth
+
+
+@pytest.mark.parametrize(
+    "pad_width",
+    [
+        2,
+        (2, 1),
+        ((2), (1)),
+        ((1, 2), (4, 5), (7, 8)),
+    ],
+)
+@pytest.mark.parametrize("constant_values", [0, 1, 150, np.nan])
+def test_pad_valid(pad_width, constant_values):
+    y = sparse.random((50, 50, 3), density=0.15, fill_value=constant_values)
+    x = y.todense()
+    xx = np.pad(x, pad_width=pad_width, constant_values=constant_values)
+    yy = np.pad(y, pad_width=pad_width, constant_values=constant_values)
+    assert_eq(xx, yy)
+
+
+@pytest.mark.parametrize(
+    "pad_width",
+    [
+        ((2, 1), (5, 7)),
+    ],
+)
+@pytest.mark.parametrize("constant_values", [150, 2, (1, 2)])
+def test_pad_invalid(pad_width, constant_values, fill_value=0):
+    y = sparse.random((50, 50, 3), density=0.15)
+    with pytest.raises(ValueError):
+        np.pad(y, pad_width, constant_values=constant_values)
+
+
+@pytest.mark.parametrize("val", [0, 5])
+def test_scalar_from_numpy(val):
+    x = np.int64(val)
+    s = sparse.COO.from_numpy(x)
+    assert s.nnz == 0
+    assert_eq(x, s)
+
+
+def test_scalar_elemwise():
+    s1 = sparse.random((), density=0.5)
+    x2 = np.random.rand(2)
+
+    x1 = s1.todense()
+
+    assert_eq(s1 * x2, x1 * x2)
